# -*- coding: utf-8 -*-
# Generated by Django 1.11.5 on 2017-10-23 14:22
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('speedinfo', '0002_auto_20171009_1219'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='viewprofiler',
            unique_together=set([('view_name', 'method')]),
        ),
    ]
